import {Connection} from "mysql";
import MysqlConnectionManager from "./MysqlConnectionManager";
import {Type} from "../Utils";

export default abstract class Migration {
    public readonly version: number;

    public constructor(version: number) {
        this.version = version;
    }

    public async shouldRun(currentVersion: number): Promise<boolean> {
        return this.version > currentVersion;
    }

    public abstract async install(connection: Connection): Promise<void>;

    public abstract async rollback(connection: Connection): Promise<void>;

    public registerModels?(): void;

    protected async query(queryString: string, connection: Connection): Promise<void> {
        await MysqlConnectionManager.query(queryString, undefined, connection);
    }
}

export interface MigrationType<M extends Migration> extends Type<M> {
    new(version: number): M;
}
